@@ -143,11 +143,12 @@ class Command(BaseCommand):
 
 
         self._copy_scripts("manage.py", "manage.py")
-        self._copy_scripts("fcgi_scripts/default.htaccess", ".htaccess")
-        self._copy_scripts("fcgi_scripts/index.fcgi", "index.fcgi")
-        self._copy_scripts("cgi_scripts/index.cgi", "index.cgi")
+        self._copy_scripts("apache_files/default.htaccess", ".htaccess")
+        self._copy_scripts("apache_files/index.fcgi", "index.fcgi")
+        self._copy_scripts("apache_files/index.wsgi", "index.wsgi")
+        self._copy_scripts("apache_files/index.cgi", "index.cgi")
+        self._copy_scripts("apache_files/index.html", "index.html")
         self._copy_scripts("local_settings_example.py", "local_settings.py")
-        self._copy_scripts("info_index.html", "index.html")
 
 
         self.stdout.write("\n")
@@ -156,10 +157,10 @@ class Command(BaseCommand):
 
 
         # Set path to PyLucid_env in file content:
-        self._patch_env_path("manage.py", "index.fcgi", "index.cgi")
+        self._patch_env_path("manage.py", "index.fcgi", "index.wsgi", "index.cgi")
 
         # Set chmod 0755 to files:
-        self._set_file_rights("manage.py", "index.fcgi", "index.cgi")
+        self._set_file_rights("manage.py", "index.fcgi", "index.wsgi", "index.cgi")
 
         django_admin_path = os.path.abspath(os.path.dirname(admin.__file__))
         django_media_src = os.path.join(django_admin_path, "media")
@@ -170,22 +171,22 @@ class Command(BaseCommand):
             [random.choice('abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)') for i in range(50)]
         )
 
-        self._patch_file("local_settings.py",
-            patch_data=[
-                (
-                    'MEDIA_ROOT = "/var/www/YourSite/media/"',
-                    'MEDIA_ROOT = "%s"' % media_dest
-                ),
-                (
-                    'SECRET_KEY = "add-a-secret-key"',
-                    'SECRET_KEY = "%s"' % secret_key
-                ),
-                (
-                    '_CACHE_PATH_PREFIX = "PyLucid"',
-                    '_CACHE_PATH_PREFIX = "%s"' % os.environ.get("USERNAME", "PyLucid")
-                )
-            ]
-        )
+        patch_data = [
+            (
+                'MEDIA_ROOT = "/var/www/YourSite/media/"',
+                'MEDIA_ROOT = "%s"' % media_dest
+            ),
+            (
+                'SECRET_KEY = "add-a-secret-key"',
+                'SECRET_KEY = "%s"' % secret_key
+            ),
+            (
+                '_CACHE_PATH_PREFIX = os.environ.get("USERNAME", "PyLucid")',
+                '_CACHE_PATH_PREFIX = "%s"' % os.environ.get("USERNAME", "PyLucid")
+            )
+        ]
+
+        self._patch_file("local_settings.py", patch_data)
 
         self.stdout.write("\n")
         self.stdout.write(" -" * 39)
