@@ -150,9 +150,12 @@ FEED_FILENAMES = (AtomFeed.filename, RssFeed.filename)
 def summary(request):
     """
     Display summary list with all blog entries.
-    
-    TODO: Set http robots ==> "noindex,follow"
     """
+    url = urlresolvers.reverse("Blog-summary")
+    if url != request.path:
+        # e.g.: request with wrong permalink: /en/blog/XXX/foobar-slug/
+        return HttpResponseRedirect(url)
+
     # Get all blog entries, that the current user can see
     paginator = BlogEntryContent.objects.get_filtered_queryset(request, filter_language=True)
 
@@ -174,6 +177,7 @@ def summary(request):
         "tag_cloud": tag_cloud,
         "CSS_PLUGIN_CLASS_NAME": settings.PYLUCID.CSS_PLUGIN_CLASS_NAME,
         "filenames": FEED_FILENAMES,
+        "page_robots": "noindex,follow",
     }
     return context
 
@@ -253,11 +257,26 @@ def detail_view(request, year, month, day, slug):
     }
     current_language = request.PYLUCID.current_language
     try:
-        content_entry = queryset.filter(**filter_kwargs).get(language=current_language)
-    except BlogEntryContent.DoesNotExist:
+        queryset = queryset.filter(**filter_kwargs)
+    except BlogEntryContent.DoesNotExist, err:
         # TODO: Try to find a entry in other language, if not exist: redirect to day_archive() ?
         # It's possible that the user comes from a external link.
-        messages.error(request, _("Entry for this url doesn't exist."))
+        msg = _("Entry for this url doesn't exist.")
+        if settings.DEBUG or request.user.is_superuser:
+            msg += " Filter kwargs: %r - error: %s" % (filter_kwargs, err)
+        messages.error(request, msg)
+        url = urlresolvers.reverse("Blog-summary")
+        return HttpResponseRedirect(url)
+
+    try:
+        content_entry, tried_languages = BlogEntryContent.objects.get_by_prefered_language(request, queryset, show_lang_errors=False)
+    except BlogEntryContent.DoesNotExist, err:
+        # TODO: Try to find a entry in other language, if not exist: redirect to day_archive() ?
+        # It's possible that the user comes from a external link.
+        msg = _("Entry for this url doesn't exist.")
+        if settings.DEBUG or request.user.is_superuser:
+            msg += " - Not found in these languages: %s - error: %s" % (",".join(tried_languages), err)
+        messages.error(request, msg)
         url = urlresolvers.reverse("Blog-summary")
         return HttpResponseRedirect(url)
 
@@ -297,7 +316,7 @@ def permalink_view(request, id, slug=None):
     prefiltered_queryset = prefiltered_queryset.filter(entry__id__exact=id)
     try:
         entry = prefiltered_queryset.filter(language__in=preferred_languages)[0]
-    except BlogEntry.DoesNotExist, IndexError:
+    except (BlogEntry.DoesNotExist, IndexError):
         # wrong permalink -> display summary
         msg = "Blog entry doesn't exist."
         if settings.DEBUG or request.user.is_staff:
